@@ -5,11 +5,11 @@ package Net::OBEX::Response::Generic;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.004';
 
 use Carp;
 use base 'Class::Data::Accessor';
-__PACKAGE__->mk_classaccessors qw( headers_length  packet  info );
+__PACKAGE__->mk_classaccessors( qw( headers_length  packet  info ) );
 
 
 my %Response_meaning_of_code = _make_response_codes();
@@ -98,6 +98,7 @@ sub _make_response_codes {
 
 __END__
 
+=encoding utf8
 
 =head1 NAME
 
